==> Calendar-Simple-v2.0.3.tar.gz: Calendar-Simple-v2.0.3/Changes.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [2.0.3] 2023-08-01

### Added

- Improvements to `pcal`

## [2.0.2] 2023-07-27

### Fixed

- Regenerated package so it includes repo and bugtracker info

## [2.0.1] 2021-01-14

### Added

- Details of bugtracker

## [2.0.0] 2020-06-22

### Changed

- Code fixes
- Refactoring to lower code complexity
- Documentation fixes (thanks MANWAR)
- Default week start date is now Monday

## [1.23] 2018-02-22

### Fixed

- Packaging

## [1.22] 2018-02-22

### Fixed

- File permissions
- Call to `timelocal()`

### Added

- CI testing

## [1.21] 2010-04-02

### Fixed

- Tests
- Perlcritic issues

## [1.20] 2008-04-19

### Added

- Minimum Perl version

## [1.19] 2008-03-09

### Added

- Licence

## [1.18] 2008-03-08

### Fixed

- "Undef" bugs
- Packaging improvements

## [1.17] 2006-10-16

### Fixed

- Packaging of `pcal` example

## [1.16] 2006-10-15

### Added

- `date_span()` function
- `pcal` example

## [1.15] 2006-10-15

### Fixed

- More idiomatic Perl
- Better tests

## [1.14] 2006-09-10

### Changed

- Switch to manual version number

## [1.13] 2005-05-31

### Fixes

- Build.PL

## [1.12] 2005-03-01

### Added

- Pod coverage tests

## [1.11] 2004-12-04

### Changed

- Skip DT tests if not installed

## [1.10] 2004-10-30

### Added

- More test coverage
- Better packaging

## [1.09] 2004-10-23

### Added

- More test coverage

## [1.08] 2003-03-14

### Added

- Support for DateTime (if it's installed)

## [1.07] 2003-02-19

### Fixed

- Problems with short weeks
- Better packaging and testing

## [1.06] 2002-07-30

### Fixed

- Fixed the previous fix

## [1.05] 2002-07-30

### Fixed

- "Undefined value" errors

## [1.04] 2002-07-13

### Changed

- Documentation fixes

## [1.03] 2002-07-12

### Added

- More documentation
- More tests

## [0.01] 2002-07-12

### Added

- All the things

==> Calendar-Simple-v2.0.4.tar.gz: Calendar-Simple-v2.0.4/Changes.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [2.0.4] 2024-05-04

### Changed

- Better variable names in `pcal`
- Better argument handling logic in `pcal`

### Fixed

- Fixed bug in example code (thanks exzr8u92)

## [2.0.3] 2023-08-01

### Added

- Improvements to `pcal`

## [2.0.2] 2023-07-27

### Fixed

- Regenerated package so it includes repo and bugtracker info

## [2.0.1] 2021-01-14

### Added

- Details of bugtracker

## [2.0.0] 2020-06-22

### Changed

- Code fixes
- Refactoring to lower code complexity
- Documentation fixes (thanks MANWAR)
- Default week start date is now Monday

## [1.23] 2018-02-22

### Fixed

- Packaging

## [1.22] 2018-02-22

### Fixed

- File permissions
- Call to `timelocal()`

### Added

- CI testing

## [1.21] 2010-04-02

### Fixed

- Tests
- Perlcritic issues

## [1.20] 2008-04-19

### Added

- Minimum Perl version

## [1.19] 2008-03-09

### Added

- Licence

## [1.18] 2008-03-08

### Fixed

- "Undef" bugs
- Packaging improvements

## [1.17] 2006-10-16

### Fixed

- Packaging of `pcal` example

## [1.16] 2006-10-15

### Added

- `date_span()` function
- `pcal` example

## [1.15] 2006-10-15

### Fixed

- More idiomatic Perl
- Better tests

## [1.14] 2006-09-10

### Changed

- Switch to manual version number

## [1.13] 2005-05-31

### Fixes

- Build.PL

## [1.12] 2005-03-01

### Added

- Pod coverage tests

## [1.11] 2004-12-04

### Changed

- Skip DT tests if not installed

## [1.10] 2004-10-30

### Added

- More test coverage
- Better packaging

## [1.09] 2004-10-23

### Added

- More test coverage

## [1.08] 2003-03-14

### Added

- Support for DateTime (if it's installed)

## [1.07] 2003-02-19

### Fixed

- Problems with short weeks
- Better packaging and testing

## [1.06] 2002-07-30

### Fixed

- Fixed the previous fix

## [1.05] 2002-07-30

### Fixed

- "Undefined value" errors

## [1.04] 2002-07-13

### Changed

- Documentation fixes

## [1.03] 2002-07-12

### Added

- More documentation
- More tests

## [0.01] 2002-07-12

### Added

- All the things
